@@ -1,5 +1,5 @@
 # vi:fdm=marker fdl=0 syntax=perl:
-# $Id: OneLiner.pm,v 1.4 2004/02/24 13:21:17 jettero Exp $
+# $Id: OneLiner.pm,v 1.1 2005/08/23 11:13:43 jettero Exp $
 
 package Net::SMTP::OneLiner;
 
@@ -13,24 +13,39 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw( send_mail );
-our $VERSION = '1.1';
+our $VERSION = "2.0";
 
 our $HOSTNAME = "localhost";
+our $PORT     = 25;
 our $ELHO     = "localhost";
 our $DEBUG    = 0;
 our $TIMEO    = 20;
 
+our $CONTENT_TYPE      = "text/plain; charset=UTF-8";
+our $TRANSFER_ENCODING = "quoted-printable";
+
 1;
 
 sub send_mail {
     my ($from, $to, $subj, $msg, $cc, $bcc, $labl) = @_;
-    my $smtp = Net::SMTP->new($HOSTNAME, Hello=>$ELHO, Timeout=>$TIMEO, Debug=>$DEBUG) or croak "$!";
 
-    $to = [ $to ] unless ref($to);
-    $cc = []      unless ref($cc);
+    my $to_hit = $HOSTNAME;
+       $to_hit .= ":$PORT" if $PORT ne "25";
+
+    my $smtp = Net::SMTP->new($to_hit, Hello=>$ELHO, Timeout=>$TIMEO, Debug=>$DEBUG) or croak $!;
+
+    $to  = [ $to  ] unless ref $to;
+    $cc  = [ $cc  ] unless ref $cc;
+    $bcc = [ $bcc ] unless ref $bcc;
+
+    @$to  = grep {defined $_} @$to;
+    @$cc  = grep {defined $_} @$cc;
+    @$bcc = grep {defined $_} @$bcc;
+
+    croak "You need to specifie at least one recipient" unless (@$to + @$cc + @$bcc) > 0;
 
     $smtp->mail($from);
-    $smtp->to(@$to);
+    $smtp->to(@$to, @$cc, @$bcc);
 
     $smtp->data;
 
@@ -42,9 +57,12 @@ sub send_mail {
     $cc = join(", ", @$cc);
 
     $smtp->datasend("From: $from\n");
-    $smtp->datasend("To: $to\n");
+    $smtp->datasend("To: $to\n") if $to;
     $smtp->datasend("CC: $cc\n") if $cc;
-    $smtp->datasend("Subject: $subj\n\n");
+    $smtp->datasend("Subject: $subj\n") if $subj;
+    $smtp->datasend("Content-Type: $CONTENT_TYPE\n");
+    $smtp->datasend("Content-Transfer-Encoding: $TRANSFER_ENCODING\n");
+    $smtp->datasend("\n");
 
     $smtp->datasend($msg);
 
@@ -85,7 +103,6 @@ Net::SMTP::OneLiner - extension that polutes the local namespace with a send_mai
 
     send_mail('me@domain', 'you@domain', "heyya there", "supz!?!?");
 
-    # $to will take a scalar argument, $cc and $bcc will not.
     # At this time, the mail server, must be the localhost.
 
 =head1 VARS
@@ -95,7 +112,13 @@ The values listed are the defaults.
 
 =head2 $Net::SMTP::OneLiner::HOSTNAME = "localhost"
 
-The hostname of the SMTP server you wish to use.
+The hostname of the SMTP server you wish to use.  This takes all the arguments
+you'd expect a IO::Socket::INET object to take.
+ 
+=head2 $Net::SMTP::OneLiner::PORT = 25;
+
+The port on the smtp server you wish to use.  If you use this, do not set the
+port in $Net::SMTP::OneLiner::HOSTNAME or you will create bugs for yourself.
 
 =head2 $Net::SMTP::OneLiner::EHLO = "localhost"
 
@@ -110,7 +133,13 @@ If this is set to true, OneLiner will tell Net::SMTP to spew forth many lines of
 
 Use this to change the communication timeout (in seconds) with the SMTP host.
 
-Your
+=head2 $Net::SMTP::OneLiner::CONTENT_TYPE = "text/plain; charset=UTF-8"
+
+Use this to change the content type (e.g. text/html).  This only changes the header and does not alter the message in any way.
+
+=head2 $Net::SMTP::OneLiner::TRANSFER_ENCODING  = "quoted-printable"
+
+Use this to change the transfer encoding.  This only changes the header and does not alter the message in any way.
 
 =head1 Bugs
 
@@ -118,8 +147,24 @@ Please report bugs immediately!  The author has not tested this
 module worth a lick -- expecting it to work just fine.  If this
 is not the case, he would like to know, so he can fix it.
 
-=head1 Author
+=head2 Bad BCC: Bug
 
-Jettero Heller jettero@cpan.org
+BCC: recipients were not working at all!  Thanks to Stephen Thomas for finding this bug.
+
+=head1 AUTHOR
+
+Paul Miller <paul@cpan.org>
+
+I am using this software in my own projects...  If you find bugs, please
+please please let me know. :) Actually, let me know if you find it handy at
+all.  Half the fun of releasing this stuff is knowing that people use it.
+
+=head1 COPYRIGHT
+
+Copyright (c) 2007 Paul Miller -- LGPL [attached]
+
+=head1 SEE ALSO
+
+perl(1)
 
 =cut
